/*
 * Copyright (C) 2023-2024
 * Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package server

import (
	"bytes"
	"github.com/stretchr/testify/assert"
	"info-manager-proxy/internal/mock"
	"net/http"
	"testing"
	"log"
    "github.com/sirupsen/logrus"
    "go.elastic.co/ecslogrus"
)

func TestRequestLoggingMiddleware(t *testing.T) {
    logger := logrus.New()
    logger.SetFormatter(&ecslogrus.Formatter{})
    log.SetOutput(logger.Writer())

	t.Run("should log request", func(t *testing.T) {
	    logger.SetLevel(logrus.InfoLevel)
		mock.SetUpGrpcServer()
		SetUpHttpGateway()

		var buf bytes.Buffer
		log.SetOutput(&buf)

		http.Get("http://localhost:8082/api/v1/information/testId")

		logOutput := buf.String()
		assert.Contains(t, "received GET request for /api/v1/information/testId with body", logOutput)
		assert.Contains(t,"successfully handled GET request for /api/v1/information/testId with body",  logOutput)
	})

	t.Run("should not log request", func(t *testing.T) {
	    logger.SetLevel(logrus.InfoLevel)
		mock.SetUpGrpcServer()
		SetUpHttpGateway()

		var buf bytes.Buffer
		log.SetOutput(&buf)

		http.Get("http://localhost:8082/")

		logOutput := buf.String()
		assert.Empty(t, logOutput)
	})
}
